# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation
import winrt.windows.ui

from winrt.windows.media.closedcaptioning import ClosedCaptionColor, ClosedCaptionEdgeEffect, ClosedCaptionOpacity, ClosedCaptionSize, ClosedCaptionStyle

Self = typing.TypeVar('Self')

@typing.final
class ClosedCaptionProperties_Static(type):
    def add_properties_changed(cls, handler: winrt.windows.foundation.EventHandler[winrt.system.Object], /) -> winrt.windows.foundation.EventRegistrationToken: ...
    def remove_properties_changed(cls, token: winrt.windows.foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def background_color(cls) -> ClosedCaptionColor: ...
    @_property
    def background_opacity(cls) -> ClosedCaptionOpacity: ...
    @_property
    def computed_background_color(cls) -> winrt.windows.ui.Color: ...
    @_property
    def computed_font_color(cls) -> winrt.windows.ui.Color: ...
    @_property
    def computed_region_color(cls) -> winrt.windows.ui.Color: ...
    @_property
    def font_color(cls) -> ClosedCaptionColor: ...
    @_property
    def font_effect(cls) -> ClosedCaptionEdgeEffect: ...
    @_property
    def font_opacity(cls) -> ClosedCaptionOpacity: ...
    @_property
    def font_size(cls) -> ClosedCaptionSize: ...
    @_property
    def font_style(cls) -> ClosedCaptionStyle: ...
    @_property
    def region_color(cls) -> ClosedCaptionColor: ...
    @_property
    def region_opacity(cls) -> ClosedCaptionOpacity: ...

@typing.final
class ClosedCaptionProperties(winrt.system.Object, metaclass=ClosedCaptionProperties_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ClosedCaptionProperties: ...

